@@ -13,17 +13,18 @@
 # under the License.
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Dict
+from typing import TYPE_CHECKING, Any, Dict, Union
 
 from supertokens_python.recipe.emailverification.interfaces import (
-    APIInterface, EmailVerifyPostInvalidTokenErrorResponse,
-    EmailVerifyPostOkResponse,
-    GenerateEmailVerifyTokenPostEmailAlreadyVerifiedErrorResponse,
-    GenerateEmailVerifyTokenPostOkResponse, IsEmailVerifiedGetOkResponse)
+    APIInterface, CreateEmailVerificationTokenEmailAlreadyVerifiedError,
+    EmailVerifyPostInvalidTokenError, EmailVerifyPostOkResult,
+    GenerateEmailVerifyTokenPostEmailAlreadyVerifiedError,
+    GenerateEmailVerifyTokenPostOkResult, IsEmailVerifiedGetOkResult,
+    VerifyEmailUsingTokenOkResult)
 
 if TYPE_CHECKING:
     from supertokens_python.recipe.emailverification.interfaces import (
-        APIOptions, GenerateEmailVerifyTokenPostResponse, IsEmailVerifiedGetResponse, EmailVerifyPostResponse
+        APIOptions
     )
 
 from supertokens_python.recipe.emailverification.types import User
@@ -31,15 +32,13 @@ from supertokens_python.recipe.session.asyncio import get_session
 
 
 class APIImplementation(APIInterface):
-    async def email_verify_post(self, token: str, api_options: APIOptions, user_context: Dict[str, Any]) -> EmailVerifyPostResponse:
+    async def email_verify_post(self, token: str, api_options: APIOptions, user_context: Dict[str, Any]) -> Union[EmailVerifyPostOkResult, EmailVerifyPostInvalidTokenError]:
         response = await api_options.recipe_implementation.verify_email_using_token(token, user_context)
-        if response.is_ok:
-            if response.user is None:
-                raise Exception("Should never come here")
-            return EmailVerifyPostOkResponse(response.user)
-        return EmailVerifyPostInvalidTokenErrorResponse()
+        if isinstance(response, VerifyEmailUsingTokenOkResult):
+            return EmailVerifyPostOkResult(response.user)
+        return EmailVerifyPostInvalidTokenError()
 
-    async def is_email_verified_get(self, api_options: APIOptions, user_context: Dict[str, Any]) -> IsEmailVerifiedGetResponse:
+    async def is_email_verified_get(self, api_options: APIOptions, user_context: Dict[str, Any]) -> IsEmailVerifiedGetOkResult:
         session = await get_session(api_options.request)
         if session is None:
             raise Exception('Session is undefined. Should not come here.')
@@ -48,9 +47,9 @@ class APIImplementation(APIInterface):
         email = await api_options.config.get_email_for_user_id(user_id, user_context)
 
         is_verified = await api_options.recipe_implementation.is_email_verified(user_id, email, user_context)
-        return IsEmailVerifiedGetOkResponse(is_verified)
+        return IsEmailVerifiedGetOkResult(is_verified)
 
-    async def generate_email_verify_token_post(self, api_options: APIOptions, user_context: Dict[str, Any]) -> GenerateEmailVerifyTokenPostResponse:
+    async def generate_email_verify_token_post(self, api_options: APIOptions, user_context: Dict[str, Any]) -> Union[GenerateEmailVerifyTokenPostOkResult, GenerateEmailVerifyTokenPostEmailAlreadyVerifiedError]:
         session = await get_session(api_options.request)
         if session is None:
             raise Exception('Session is undefined. Should not come here.')
@@ -59,13 +58,11 @@ class APIImplementation(APIInterface):
         email = await api_options.config.get_email_for_user_id(user_id, user_context)
 
         token_result = await api_options.recipe_implementation.create_email_verification_token(user_id, email, user_context)
-        if token_result.is_email_already_verified:
-            return GenerateEmailVerifyTokenPostEmailAlreadyVerifiedErrorResponse()
+        if isinstance(token_result, CreateEmailVerificationTokenEmailAlreadyVerifiedError):
+            return GenerateEmailVerifyTokenPostEmailAlreadyVerifiedError()
 
         user = User(user_id, email)
 
-        if token_result.token is None:
-            raise Exception("Should never come here")
         email_verify_link = (await api_options.config.get_email_verification_url(
             user, user_context)) + '?token=' + token_result.token + '&rid' + api_options.recipe_id
 
@@ -74,4 +71,4 @@ class APIImplementation(APIInterface):
         except Exception:
             pass
 
-        return GenerateEmailVerifyTokenPostOkResponse()
+        return GenerateEmailVerifyTokenPostOkResult()
